<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ru">
<context>
    <name>File</name>
    <message>
        <location filename="../File.js" line="+65"/>
        <source>File Tools</source>
        <translation>Инструменты работы с файлами</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Show file tools</source>
        <translation>Показать инструменты работы с файлами</translation>
    </message>
    <message>
        <location line="+22"/>
        <source>&amp;File</source>
        <translation>Файл</translation>
    </message>
    <message>
        <location line="+91"/>
        <location line="+69"/>
        <source>Format:</source>
        <translation>Формат:</translation>
    </message>
    <message>
        <location line="-32"/>
        <source>Overwrite File?</source>
        <translation>Перезаписать файл?</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>The file &apos;%1&apos; already exists. Do you wish to overwrite it?</source>
        <translation>Файл с именем «%1» уже существует. Заменить его?</translation>
    </message>
    <message>
        <location line="+20"/>
        <source>All Files</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
